$<-
operator. This method is never called explicitly, but through an indirect
usage of the $<- operator, e.g. obj$name <- "foo".
setmethod, e.g. if name has the value()
"age", a setAge() will
be looked for. If such a method exists it will be called with the Class
as the first argument and value as the second, e.g.
setAge(this, value).
A get() is only looked for if is not a
private field. A private field is a name beginning with a
. (period). The rational for this naming convention is to be
consistent with how ls() works, which will not
list such members by default.
value to a
(existing or a non-existing) field named name.
Because any
setis called first, it is possible to encapsulate (hide away) fields with certain names or to put restrictions to what values can be assigned to them.()
"$"(this, name) <- value "[["(this, name) <- valuesetmethod or the name of the field to be assigned the new value.()
this, as all $<- methods must do.
Class.